@@ -18,15 +18,15 @@ def get_version_generic(project_type):
         retrieve_ver_command = ''        
          
     
-def change_manifest():
+def change_manifest(v, dv):
     ## Retreive version number manifest
     ## grep "version\s*=\s*" manifest.yml  ## To-do Refactor to use this 
-    
+    path = __main__.os.path.abspath(__main__.os.getcwd()) 
     ## check if manifest.yml exist
-    sed_command_manifest = "sed -i 's/version: {}/version: {}/g' ./manifest.yml".format(version.rstrip(), new_version)
+    sed_command_manifest = "sed -i 's/version: {}/version: {}/g' ./manifest.yml".format(v.rstrip(), dv)
  
     ## update version number in manifest.yml
-    process_sed_manifest = __main__.Popen(sed_command_manifest, shell=True, stdout=__main__.subprocess.PIPE, cwd=path)
+    process_sed_manifest = __main__.Popen(sed_command_manifest, shell=True, stdout=__main__.PIPE, cwd=path)
 
 def modify_version():
     if __main__.arch_type == 'npm':
@@ -90,13 +90,13 @@ def modify_version():
         sed_command = "sed -i 's/\"version\": \"{}\"/\"version\": \"{}\"/g' ./package.json".format(version.rstrip(), new_version)
         ## print('SED command: ', sed_command)
         
-        process_sed = __main__.Popen(sed_command, shell=True, stdout=__main__.subprocess.PIPE, cwd=path)
+        process_sed = __main__.Popen(sed_command, shell=True, stdout=__main__.PIPE, cwd=path)
         
-        change_manifest()  ## Update manifest file
+        change_manifest(version, new_version)  ## Update manifest file
     
         print("Previous version: ", version.rstrip(), "  New Version:: ", new_version, "   Type: ", __main__.change_type)
         
-        return sys.exit(0)
+        return __main__.sys.exit(0)
   
     elif __main__.arch_type == 'springboot':
         print("Architecture: Springboot: Java")
@@ -104,12 +104,12 @@ def modify_version():
         ## update version number in package.json
         sed_buildgradle_command = "sed -i 's/\"version\": \"{}\"/\"version\": \"{}\"/g' ./build.gradle".format(version.rstrip(), new_version)
         ## print('SED command: ', sed_command)
-        process_sed = __main__.Popen(sed_buildgradle_command, shell=True, stdout=__main__.subprocess.PIPE, cwd=path)
+        process_sed = __main__.Popen(sed_buildgradle_command, shell=True, stdout=__main__.PIPE, cwd=path)
         
-        return sys.exit(0)
+        return __main__.sys.exit(0)
     elif __main__.arch_type == 'dotnet':
         print("Architecture: .NET")
-        return sys.exit(0)
+        return __main__.sys.exit(0)
     else: 
         print("Error: Cannot parse command")
-        return sys.exit()
\ No newline at end of file
+        return __main__.sys.exit()
\ No newline at end of file
