@@ -5,7 +5,7 @@ def commit_push_changes():
     print("Committing changes:::")
     path = __main__.os.path.abspath(__main__.os.getcwd())   
     git_commit_command = "git commit -am '{}'".format(commit_message)
-    process_git_commit = __main__.Popen(git_commit_command, shell=True, stdout=__main__.subprocess.PIPE, cwd=path)
+    process_git_commit = __main__.Popen(git_commit_command, shell=True, stdout=__main__.PIPE, cwd=path)
     print("Commit result: ", process_git_commit.communicate()[0])
         
     auth = "//" + __main__.os.environ.get('GITLAB_USER_LOGIN') + ":" + __main__.os.environ.get('PRIVATE_TOKEN') + "@"
